@@ -9,7 +9,6 @@
 ***************************************************************************/
 #include "KBlocksGameLogic.h"
 
-#include <QtGlobal>
 
 KBlocksGameLogic::KBlocksGameLogic(int capacity, bool record)
 {
@@ -30,7 +29,7 @@ KBlocksGameLogic::KBlocksGameLogic(int capacity, bool record)
     if (record) {
         mpGameRecorder = new KBlocksGameRecorder();
     } else {
-        mpGameRecorder = 0;
+        mpGameRecorder = nullptr;
     }
     mpGameReplayer = 0;
 }
